SystemOrganization addCategory: #GODBasesTests!

TestCase subclass: #GDBClientControllerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODBasesTests'!

!GDBClientControllerTest methodsFor: 'helper' stamp: 'lacm 11/30/2014 17:50'!
conferencesCollection
	^ GDBConference databaseConference.! !

!GDBClientControllerTest methodsFor: 'helper' stamp: 'lacm 11/30/2014 17:38'!
currentClientName
^ GDBMagmaClient session user id! !

!GDBClientControllerTest methodsFor: 'helper' stamp: 'lacm 11/30/2014 17:50'!
godDataCollection
	^ GDBData database.! !

!GDBClientControllerTest methodsFor: 'initialize-release' stamp: 'lacm 12/1/2014 21:36'!
setUp

	self timeout: 15.
	GDBMagmaClient aClientName: 'default_user'.
	GDBClientController initializeSession.! !

!GDBClientControllerTest methodsFor: 'initialize-release' stamp: 'lacm 12/1/2014 21:36'!
tearDown
	"comment stating purpose of message"

	GDBClientController release.
! !

!GDBClientControllerTest methodsFor: 'tests' stamp: 'lacm 11/30/2014 18:29'!
testClientSessionIsChanged
	
	self should: [self currentClientName = 'default_user'].

	GDBClientController refresh: 'otherClient'.
	self should: [self currentClientName = 'otherClient'].! !

!GDBClientControllerTest methodsFor: 'tests' stamp: 'lacm 11/30/2014 17:45'!
testClientSessionIsStarted

self should: [self currentClientName = 'default_user'].
GDBClientController release.

GDBClientController initializeSession.
self should: [self currentClientName = 'default_user'].
! !

!GDBClientControllerTest methodsFor: 'tests' stamp: 'lacm 12/1/2014 09:57'!
testDataRefreshByDifferentClients
	| GODDataA GODDataB 
	myKeywords myImportantDates myVenue myConference myCollection|
		
	"GODData transactions"	
	GODDataA:=	GODData new author: 'author A'; title: 'title A'; yourself.		
	GODDataB:=	GODData new author: 'author B'; title: 'title B'; yourself.		
								
	"GODConference transactions"	
	myKeywords:= Set new add: 'neural'; add: 'genetic'; yourself.
	myImportantDates:= GCImportantDates new deadlineDate:'24 mar 14';
											startDate: '20 abr 14';
											endDate: '25 abr 14'; yourself.
	myVenue:= GCVenue new city: 'Holywood'; country: 'USA'; yourself.
	myConference := GCConference new   acronym:'aia'; 
										name:'Artificial Intelligence and Applications'; 
										keywords: myKeywords;
										url: 'http://conferences';
										importantDates: myImportantDates;
										venue: myVenue;
										yourself.
										
	myCollection := OrderedCollection new add: myConference; yourself.

	"default user"
	self should: [self currentClientName = 'default_user'].
	GDBDatabase createDatabase.	
	GDBData add: GODDataA.
	
	GDBClientController refresh.
	self should: [self currentClientName = 'default_user'].
	self should: [self godDataCollection size = 1].	
	self should: [self conferencesCollection size = 0].
	GDBData add: GODDataB.

	"other user"	
	GDBClientController refresh: 'otherClient'.
	self should: [self currentClientName = 'otherClient'].
	GDBConference saveConferences: myCollection.	
		
	GDBClientController refresh.
		
	self should: [self currentClientName = 'otherClient'].
	self should: [self godDataCollection size = 2].	
	self should: [self conferencesCollection size = 1].

     GDBDatabase resetAllDatabase.
! !

!GDBClientControllerTest methodsFor: 'tests' stamp: 'lacm 12/1/2014 09:56'!
testDifferentClientTransactionsIsSaved
	| GODDataA GODDataB GODDataC
	myKeywords myImportantDates myVenue myConference myCollection|

	"GODData transactions"	
	GODDataA:=	GODData new author: 'author A'; title: 'title A'; yourself.		
	GODDataB:=	GODData new author: 'author B'; title: 'title B'; yourself.		
	GODDataC:=	GODData new author: 'author C'; title: 'title C'; yourself.		
				
	"GCConference transactions"	
	myKeywords:= Set new add: 'neural'; add: 'genetic'; yourself.
	myImportantDates:= GCImportantDates new deadlineDate:'24 mar 14';
											startDate: '20 abr 14';
											endDate: '25 abr 14'; yourself.
	myVenue:= GCVenue new city: 'Holywood'; country: 'USA'; yourself.
	myConference := GCConference new   acronym:'aia'; 
										name:'Artificial Intelligence and Applications'; 
										keywords: myKeywords;
										url: 'http://conferences';
										importantDates: myImportantDates;
										venue: myVenue;
										yourself.										
	myCollection := OrderedCollection new add: myConference; yourself.

	"default user"
	self should: [self currentClientName = 'default_user'].
	GDBDatabase createDatabase.			
	GDBData add: GODDataA.
	GDBConference saveConferences: myCollection.	

	"other user"	
	GDBClientController refresh: 'otherClient'.
	self should: [self currentClientName = 'otherClient'].
	GDBData add: GODDataB.				
	GDBData add: GODDataC.

	"default user"	
	GDBClientController refresh: 'default_user'.
	self should: [self currentClientName = 'default_user'].
	self should: [self godDataCollection size = 3].	
	self should: [self conferencesCollection size = 1].

     GDBDatabase resetAllDatabase.
! !

!GDBClientControllerTest methodsFor: 'tests' stamp: 'lacm 11/30/2014 18:44'!
testRepositoryEmptyDatabaseIsCreated

	self should: [self currentClientName = 'default_user'].
	
	GDBDatabase createDatabase.	
	
	self should: [self godDataCollection size = 0].
	self should: [self conferencesCollection size = 0].
! !

TestCase subclass: #GDBConferenceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODBasesTests'!

!GDBConferenceTest methodsFor: 'helper' stamp: 'lacm 11/30/2014 16:15'!
conferencesCollection
	^ GDBConference databaseConference.! !

!GDBConferenceTest methodsFor: 'helper' stamp: 'lacm 11/30/2014 16:15'!
godDataCollection
	^ GDBData database.! !

!GDBConferenceTest methodsFor: 'initialize-release' stamp: 'lacm 12/1/2014 21:37'!
setUp	
	self timeout: 15.
	GDBClientController initializeSession.
	GDBDatabase createDatabase.
! !

!GDBConferenceTest methodsFor: 'initialize-release' stamp: 'lacm 12/1/2014 21:37'!
tearDown
	"comment stating purpose of message"

	GDBDatabase resetAllDatabase.
	GDBClientController release.! !

!GDBConferenceTest methodsFor: 'tests' stamp: 'lacm 11/30/2014 16:16'!
testAddConferencesDataIsSaved
	|myKeywords myImportantDates myVenue myConference myCollection|
		
	myKeywords:= Set new add: 'neural'; add: 'genetic'; yourself.
	myImportantDates:= GCImportantDates new deadlineDate:'24 mar 14';
											startDate: '20 abr 14';
											endDate: '25 abr 14'; yourself.
	myVenue:= GCVenue new city: 'Holywood'; country: 'USA'; yourself.
	myConference := GCConference new   acronym:'aia'; 
										name:'Artificial Intelligence and Applications'; 
										keywords: myKeywords;
										url: 'http://conferences';
										importantDates: myImportantDates;
										venue: myVenue;
										yourself.
										
	myCollection := OrderedCollection new add: myConference; yourself.

	GDBConference saveConferences: myCollection.	
	GDBClientController release.
	
	self should:[self conferencesCollection size = 1].
	
	GDBClientController initializeSession.! !

!GDBConferenceTest methodsFor: 'tests' stamp: 'lacm 11/30/2014 17:13'!
testGODConferenceRepositoryEmptyDatabase
	
	self should: [self conferencesCollection size = 0].! !

!GDBConferenceTest methodsFor: 'tests' stamp: 'lacm 11/30/2014 16:17'!
testLoadConferencesData
	|retrievedCollection myKeywords myImportantDates myVenue myConference myCollection|
		
	myKeywords:= Set new add: 'neural'; add: 'genetic'; yourself.
	myImportantDates:= GCImportantDates new deadlineDate:'24 mar 14';
											startDate: '20 abr 14';
											endDate: '25 abr 14'; yourself.
	myVenue:= GCVenue new city: 'Holywood'; country: 'USA'; yourself.
	myConference := GCConference new   acronym:'aia'; 
										name:'Artificial Intelligence and Applications'; 
										keywords: myKeywords;
										url: 'http://conferences';
										importantDates: myImportantDates;
										venue: myVenue;
										yourself.
										
	myCollection := OrderedCollection new add: myConference; yourself.

	GDBConference saveConferences: myCollection.	
	GDBClientController release.
	
	GDBClientController initializeSession.
	retrievedCollection:= GDBConference loadConferences.	
		
	self should:[retrievedCollection size = 1].
! !

!GDBConferenceTest methodsFor: 'tests' stamp: 'lacm 11/30/2014 16:17'!
testResetConferencesData
	|myGODData myKeywords myImportantDates myVenue myConference myCollection|
	"saving a GODData object"
	myGODData:=	GODData new author: 'author A'; title: 'title A'; yourself.		
	GDBData add: myGODData.		
		
	"saving a collection of GCConference objects"
	myKeywords:= Set new add: 'neural'; add: 'genetic'; yourself.
	myImportantDates:= GCImportantDates new deadlineDate:'24 mar 14';
											startDate: '20 abr 14';
											endDate: '25 abr 14'; yourself.
	myVenue:= GCVenue new city: 'Holywood'; country: 'USA'; yourself.
	myConference := GCConference new   acronym:'aia'; 
										name:'Artificial Intelligence and Applications'; 
										keywords: myKeywords;
										url: 'http://conferences';
										importantDates: myImportantDates;
										venue: myVenue;
										yourself.										
	myCollection := OrderedCollection new add: myConference; yourself.
	GDBConference saveConferences: myCollection.		

	GDBClientController release.			
	self should: [self godDataCollection size = 1].				
	self should:[self conferencesCollection size = 1].
	
	GDBClientController initializeSession.
	GDBConference resetConferenceData.
	
	self should:[self conferencesCollection size = 0].
	self should:[self godDataCollection size = 1].
! !

TestCase subclass: #GDBDataTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODBasesTests'!

!GDBDataTest methodsFor: 'helper' stamp: 'lacm 11/30/2014 15:46'!
conferencesCollection
	^ GDBConference databaseConference.! !

!GDBDataTest methodsFor: 'helper' stamp: 'lacm 11/30/2014 15:46'!
godDataCollection
	^ GDBData database.! !

!GDBDataTest methodsFor: 'initialize-release' stamp: 'lacm 12/1/2014 21:38'!
setUp	
	self timeout: 15.
	GDBClientController initializeSession.
	GDBDatabase createDatabase.
! !

!GDBDataTest methodsFor: 'initialize-release' stamp: 'lacm 12/1/2014 21:39'!
tearDown
	"comment stating purpose of message"

	GDBDatabase resetAllDatabase.
	GDBClientController release.



	
	! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/30/2014 15:47'!
testAddANoGodData
	|aNotGODData|
	aNotGODData :=	'Just a string'.	
	self should:[GDBData add: aNotGODData] raise: GDBDataMustBeAnGODData .
! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/30/2014 15:49'!
testAddDuplicatedGODData
	|myGODData|
		
	myGODData:=	GODData new author:'author A'; title: 'title A'; yourself.
	GDBData add: myGODData.
	
	self should:[GDBData add: myGODData] raise: GODDataAlreadyExistsInTheDatabase.! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/30/2014 15:50'!
testAddGODDataIsSaved
	|retrievedLastGODData myGODData|			
	
	myGODData:=	GODData new author: 'author A'; title: 'title A'; yourself.		
	GDBData add: myGODData.		
	GDBClientController release.		
			
	self should: [self godDataCollection size = 1].	
	retrievedLastGODData:= self godDataCollection detectMax:[:each | each id].	
	self should: [retrievedLastGODData id > 0]. 
	GDBClientController initializeSession.! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/30/2014 15:50'!
testAddGODDataWithoutAuthor
	|myGODData|
		
	myGODData:=	GODData new title: 'title A'; yourself.
	
	self should:[GDBData add: myGODData] raise: GODDataAuthorMustContainsSomeInformation .! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/30/2014 15:50'!
testAddGODDataWithoutTitle
	|aGODData|
	aGODData :=	GODData new author: 'autor A'; yourself.
	self should:[GDBData add: aGODData] raise: GODDataTitleMustContainsSomeInformation .! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 12/1/2014 21:59'!
testExactSearchByAuthor
	| a b c  collection|
	a := GODData new author: 'author A'; title: 'title A'; yourself.
	b := GODData new author: 'author A'; title: 'title B'; yourself.
	c := GODData new author: 'author B'; title: 'title A'; yourself.

	GDBData add: a; add: b; add: c.
	
	collection:=GDBData exactSearchByAuthor: 'author A'.

	self should: [collection size = 2].
	
	collection:=GDBData exactSearchByAuthor: 'author'.

	self should: [collection = nil].
! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 12/1/2014 20:30'!
testExactSearchByTitle
	| a b c  collection|
	a := GODData new author: 'author A'; title: 'title A'; yourself.
	b := GODData new author: 'author A'; title: 'title B'; yourself.
	c := GODData new author: 'author B'; title: 'title A'; yourself.

	GDBData add: a; add: b; add: c.
	
	collection:=GDBData exactSearchByTitle: 'title B'.

	self should: [collection size = 1].! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/30/2014 17:12'!
testGODDataRepositoryEmptyDatabase
	
	self should: [self godDataCollection size = 0].
! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/30/2014 15:51'!
testGetAll
	| a b c collection|
	a := GODData new author: 'author A'; title: 'title A'; yourself.
	b := GODData new author: 'author A'; title: 'title B'; yourself.
	c := GODData new author: 'author B'; title: 'title A'; yourself.

	GDBData add: a; add: b; add: c.
	collection :=  GDBData getAll.
	self should: [collection size = 3].
! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/30/2014 15:53'!
testRemoveGODDataIsSaved
	|removedGODData|
       removedGODData:= GODData new author: 'author B';
										  title: 'title B' ;
										  yourself.		
	GDBData add: removedGODData.
	
	self should: [self godDataCollection size = 1].
	
	GDBData remove: removedGODData.	
	
	GDBClientController release.
	
	self should:[self godDataCollection size = 0].
	GDBClientController initializeSession.! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/30/2014 15:58'!
testResetGODData
	|myGODData myKeywords myImportantDates myVenue myConference myCollection|
	"saving a GODData object"
	myGODData:=	GODData new author: 'author A'; title: 'title A'; yourself.		
	GDBData add: myGODData.		
		
	"saving a collection of GCConference objects"
	myKeywords:= Set new add: 'neural'; add: 'genetic'; yourself.
	myImportantDates:= GCImportantDates new deadlineDate:'24 mar 14';
											startDate: '20 abr 14';
											endDate: '25 abr 14'; yourself.
	myVenue:= GCVenue new city: 'Holywood'; country: 'USA'; yourself.
	myConference := GCConference new   acronym:'aia'; 
										name:'Artificial Intelligence and Applications'; 
										keywords: myKeywords;
										url: 'http://conferences';
										importantDates: myImportantDates;
										venue: myVenue;
										yourself.										
	myCollection := OrderedCollection new add: myConference; yourself.
	GDBConference saveConferences: myCollection.		

	GDBClientController release.			
	self should: [self godDataCollection size = 1].				
	self should:[self conferencesCollection size = 1].
	
	GDBClientController initializeSession.
	GDBData resetData.
	
	self should:[self conferencesCollection size = 1].
	self should:[self godDataCollection size = 0].
! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 12/1/2014 21:32'!
testSearchAuthor
	| a b c collection|
	a := GODData new author: 'one author A'; title: 'one title A'; yourself.
	b := GODData new author: 'other author A'; title: 'other title B'; yourself.
	c := GODData new author: 'my favorite author'; title: 'my favorite title'; yourself.

	GDBData add: a; add: b; add: c.

	collection :=  GDBData searchAuthor: 'author'.
	self should: [collection size = 3].

	collection :=  GDBData searchAuthor: 'favorite'.
	self should: [collection size = 1].

	collection :=  GDBData searchAuthor: 'author B'.
	self should: [collection = nil].
! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/30/2014 16:00'!
testSearchById
	| a b c  aGODData|
	a := GODData new author: 'author A'; title: 'title A'; yourself.
	b := GODData new author: 'author A'; title: 'title B'; yourself.
	c := GODData new author: 'author B'; title: 'title A'; yourself.

	GDBData add: a; add: b; add: c.
	
	aGODData:=GDBData searchById: 1.

	self should: [aGODData id = 1].
	self should: [aGODData author = 'author A'].
	self should: [aGODData title = 'title A'].! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/30/2014 16:01'!
testSearchFor
	| a b c collection aBlock|
	a := GODData new author: 'author A'; title: 'title A'; yourself.
	b := GODData new author: 'author A'; title: 'title B'; yourself.
	c := GODData new author: 'author B'; title: 'title A'; yourself.

	GDBData add: a; add: b; add: c.
	aBlock := [:obj | obj author = 'author A'].
	collection :=  GDBData searchFor: aBlock.
	self should: [collection size = 2].
! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 12/1/2014 21:32'!
testSearchTitle
	| a b c collection|
	a := GODData new author: 'one author A'; title: 'one title A'; yourself.
	b := GODData new author: 'other author A'; title: 'other title B'; yourself.
	c := GODData new author: 'my favorite author'; title: 'my favorite title'; yourself.

	GDBData add: a; add: b; add: c.

	collection :=  GDBData searchTitle: 'title'.
	self should: [collection size = 3].

	collection :=  GDBData searchTitle: 'other'.
	self should: [collection size = 1].

	collection :=  GDBData searchTitle: 'title C'.
	self should: [collection = nil].
! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 12/1/2014 21:33'!
testUpdateAGODDataObject
	|oldGODData newGODData myReader|
	"saving a oldGODData object"
	oldGODData:=	GODData new author: 'author A'; title: 'title A'; yourself.		
	GDBData add: oldGODData.		

	myReader := GDBData searchAuthor: 'author A'.	
	self should: [myReader size = 1].
	myReader := nil.
	
	newGODData:=	 GODData new author: 'author B'; title: 'title A'; yourself.				
	GDBData update: oldGODData with: newGODData.
	
	GDBClientController release.
	self should: [self godDataCollection size = 1].							

	GDBClientController initializeSession.			

	myReader := GDBData searchAuthor: 'author B'.	
	self should:[myReader size = 1].
	
	myReader := GDBData searchAuthor: 'author A'.	
	self should:[myReader = nil].! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/30/2014 16:04'!
testUpdateANoNewGodData
	|aNotGODData aOldGODData|
	aNotGODData :=	'Just a string'.	
	aOldGODData:= GODData new.		
	self should:[GDBData update: aOldGODData with: aNotGODData] raise: GDBDataMustBeAnGODData .
! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/30/2014 16:04'!
testUpdateANoOldGodData
	|aNotGODData aNewGODData|
	aNotGODData :=	'Just a string'.	
	aNewGODData:= GODData new.		
	self should:[GDBData update: aNotGODData with: aNewGODData] raise: GDBDataMustBeAnGODData .
! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/30/2014 16:05'!
testUpdateNewGODDataWithoutAuthor
	|oldGODData newGODData|
	
	oldGODData:=	GODData new author: 'author A'; title: 'title A'; yourself.	
	newGODData:=	GODData new title: 'title B'; yourself.
		
	self should:[GDBData update: oldGODData with:newGODData] raise: GODDataAuthorMustContainsSomeInformation .! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/30/2014 16:05'!
testUpdateNewGODDataWithoutTitle
	|oldGODData newGODData|
	
	oldGODData:=	GODData new author: 'author A'; title: 'title A'; yourself.	
	newGODData:=	GODData new author: 'author B';  yourself.
		
	self should: [GDBData update: oldGODData with:newGODData] raise: GODDataTitleMustContainsSomeInformation .! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/30/2014 16:05'!
testUpdateOldGODDataWithoutAuthor
	|oldGODData newGODData|
	
	oldGODData:=	GODData new title: 'title A'; yourself.	
	newGODData:=	GODData new author: 'author A'; title: 'title B'; yourself.
		
	self should:[GDBData update: oldGODData with: newGODData] raise: GODDataAuthorMustContainsSomeInformation .! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/30/2014 16:06'!
testUpdateOldGODDataWithoutTitle
	|oldGODData newGODData|
	
	oldGODData:=	GODData new author: 'author A'; yourself.	
	newGODData:=	GODData new author: 'author B'; title: 'title B'; yourself.
		
	self should: [GDBData update: oldGODData with: newGODData] raise: GODDataTitleMustContainsSomeInformation.! !

TestCase subclass: #GDBDatabaseTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODBasesTests'!

!GDBDatabaseTest methodsFor: 'helper' stamp: 'lacm 11/30/2014 16:11'!
conferencesCollection
	^ GDBConference databaseConference.! !

!GDBDatabaseTest methodsFor: 'helper' stamp: 'lacm 11/30/2014 16:11'!
godDataCollection
	^ GDBData database.! !

!GDBDatabaseTest methodsFor: 'initialize-release' stamp: 'lacm 12/1/2014 21:55'!
setUp	
	self timeout: 15.
	GDBClientController initializeSession.
	GDBDatabase createDatabase.
! !

!GDBDatabaseTest methodsFor: 'initialize-release' stamp: 'lacm 12/1/2014 21:55'!
tearDown
	"comment stating purpose of message"

	GDBDatabase resetAllDatabase.
	GDBClientController release.



	
	! !

!GDBDatabaseTest methodsFor: 'tests' stamp: 'lacm 11/30/2014 16:12'!
testRepositoryEmptyDatabase
	
	self should: [self godDataCollection size = 0].
	self should: [self conferencesCollection size = 0].
! !

!GDBDatabaseTest methodsFor: 'tests' stamp: 'lacm 11/30/2014 16:12'!
testResetAllDatabase
	|myGODData myKeywords myImportantDates myVenue myConference myCollection|
	"saving a GODData object"
	myGODData:=	GODData new author: 'author A'; title: 'title A'; yourself.		
	GDBData add: myGODData.		
		
	"saving a collection of GCConference objects"
	myKeywords:= Set new add: 'neural'; add: 'genetic'; yourself.
	myImportantDates:= GCImportantDates new deadlineDate:'24 mar 14';
											startDate: '20 abr 14';
											endDate: '25 abr 14'; yourself.
	myVenue:= GCVenue new city: 'Holywood'; country: 'USA'; yourself.
	myConference := GCConference new   acronym:'aia'; 
										name:'Artificial Intelligence and Applications'; 
										keywords: myKeywords;
										url: 'http://conferences';
										importantDates: myImportantDates;
										venue: myVenue;
										yourself.										
	myCollection := OrderedCollection new add: myConference; yourself.
	GDBConference saveConferences: myCollection.		
	
	GDBClientController release.
	self should: [self godDataCollection size = 1].				
	self should:[self conferencesCollection size = 1].
	
	GDBClientController initializeSession.
	GDBDatabase resetAllDatabase.
	
	self should:[self conferencesCollection size = 0].
	self should:[self godDataCollection size = 0].
! !

TestCase subclass: #GDBServerControllerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODBasesTests'!

!GDBServerControllerTest methodsFor: 'helper' stamp: 'lacm 12/1/2014 11:55'!
currentOpenRepository
	
	^ GDBServerController uniqueServerInstance repositoryName.! !

!GDBServerControllerTest methodsFor: 'initialize-release' stamp: 'lacm 12/1/2014 21:55'!
setUp

	self timeout: 30.	
	GDBServerController stopServer. 
	GDBServerController createRepository.
	GDBServerController startServer.! !

!GDBServerControllerTest methodsFor: 'initialize-release' stamp: 'lacm 12/1/2014 21:55'!
tearDown
		"comment stating purpose of message"

	GDBServerController stopServer.! !

!GDBServerControllerTest methodsFor: 'tests' stamp: 'lacm 12/1/2014 14:23'!
testDefaultRepositoryIsCreated

	self should:[(GDBServerController uniqueServerInstance isCreated: 'default_repository') = true].
	self should:[self currentOpenRepository = 'default_repository' ].
! !

!GDBServerControllerTest methodsFor: 'tests' stamp: 'lacm 12/1/2014 14:23'!
testServerIsStopped

	GDBServerController stopServer.
	
	self should:[ GDBServerController isStarted = false].
	
	! !

!GDBServerControllerTest methodsFor: 'tests' stamp: 'lacm 12/1/2014 22:13'!
testServerWithASpecificRepositoryIsStarted
	|otherRepository|
	
	self should:[self currentOpenRepository = 'default_repository'].
	GDBServerController stopServer.
	
	otherRepository:='otherRepository'.
	GDBServerController startServer: otherRepository.

	self should:[(GDBServerController uniqueServerInstance isCreated: otherRepository) = true].
	self should:[self currentOpenRepository = otherRepository].
					
	GDBServerController deleteRepository: otherRepository.
	
	self should:[(GDBServerController uniqueServerInstance isCreated: otherRepository) = false].

   ! !

!GDBServerControllerTest methodsFor: 'tests' stamp: 'lacm 12/1/2014 14:22'!
testServerWithDefaultRepositoryIsStarted

	self should:[GDBServerController isStarted = true].
	self should:[self currentOpenRepository = 'default_repository'].
! !

!GDBServerControllerTest methodsFor: 'tests' stamp: 'lacm 12/1/2014 14:22'!
testSpecificRepositoryIsCreatedAndDeleted
	|server aRepositoryName|
	server := GDBServerController uniqueServerInstance.

	self should: [self currentOpenRepository = 'default_repository' ].

	GDBServerController stopServer.
	
	aRepositoryName:='other_repository'.
	GDBServerController createRepository: aRepositoryName.
	
	self should:[(server isCreated: aRepositoryName) = true].	
	
	GDBServerController deleteRepository: aRepositoryName.
	self should:[(server isCreated: aRepositoryName) = false].! !
